fourteatoo.mqhub.action


default-ntfy-urlclj

source

delay-callclj

(delay-call delay f)
(delay-call delay id f)
source

discord-sendclj

(discord-send content
              &
              {:keys [webhook description title color fields footer]
               :or {color 3066993 title (conf :discord :title)}})
source

execute-actioncljmultimethod

source

execute-actionsclj

(execute-actions actions topic data)
source

ignore-timesclj

(ignore-times times-threshold timeout-secs ctx)
source

logclj

(log message)
(log level message)
source

mail-sendclj

(mail-send message & {:as args})

message is a string. Additional key arguments are passed along to the SMTP server. Examples are :to, :subject, :from, etc, and can have defaults in the [:smtp :message] configuration.

`message` is a string.  Additional key arguments are passed along to
the SMTP server.  Examples are :to, :subject, :from, etc, and can
have defaults in the `[:smtp :message]` configuration.
sourceraw docstring

make-code-fnclj

(make-code-fn args code)
source

make-topic-listenerclj

(make-topic-listener configuration)
source

mqtt-publishclj

(mqtt-publish topic message & [encoding])
source

notifyclj

(notify message)
source

ntfy-sendclj

(ntfy-send
  message
  &
  {:keys [topic title] :as opts :or {title (or (conf :ntfy :title) "MQHUB")}})
source

scheduledclj

source

sleepclj

(sleep secs)
source

telegram-sendclj

(telegram-send message & {:keys [chat-id]})
source

with-insistencecljmacro

(with-insistence [ignored-times span] & body)
source

cljdoc builds & hosts documentation for Clojure/Script libraries