fourteatoo.mqhub.exenv

Namespace for the execution of the exec scripts. Exec scripts in the configuration file are evaluated within this namespace so as to set some handy shorthands and limit visibility if necessary.

Namespace for the execution of the exec scripts.  Exec scripts in the
configuration file are evaluated within this namespace so as to set
some handy shorthands and limit visibility if necessary.
raw docstring

No vars found in this namespace.

cljdoc builds & hosts documentation for Clojure/Script libraries