The Blink Camera module, implementing the monitoring of the Blink system and the actions applicable to it.
The Blink Camera module, implementing the monitoring of the Blink system and the actions applicable to it.
The EVO Home module, implementing the monitoring of the Honeywell system and the actions applicable to it.
The EVO Home module, implementing the monitoring of the Honeywell system and the actions applicable to it.
Namespace for the execution of the exec scripts. Exec scripts in the configuration file are evaluated within this namespace so as to set some handy shorthands and limit visibility if necessary.
Namespace for the execution of the exec scripts. Exec scripts in the configuration file are evaluated within this namespace so as to set some handy shorthands and limit visibility if necessary.
No vars found in this namespace.
No vars found in this namespace.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |