(discord-send content
&
{:keys [webhook description title color fields footer]
:or {color 3066993 title (conf :discord :title)}})(mail-send message & {:as args})message is a string. Additional key arguments are passed along to
the SMTP server. Examples are :to, :subject, :from, etc, and can
have defaults in the [:smtp :message] configuration.
`message` is a string. Additional key arguments are passed along to the SMTP server. Examples are :to, :subject, :from, etc, and can have defaults in the `[:smtp :message]` configuration.
(ntfy-send
message
&
{:keys [topic title] :as opts :or {title (or (conf :ntfy :title) "MQHUB")}})cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |